==> vue-column-list-group-2.23.0.tgz: package/lib/index.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/column-list-group/vue';
import { defineComponent, $prefix, $props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "w-full",
    class: _vm.type !== "list" ? "[&_[role=column-list-item]]:mb-3 [&_[role=column-list-item]:last-child]:mb-0" : "",
    attrs: {
      "data-tag": "tiny-column-list-group"
    }
  }, [_vm._t("default")], 2);
};
var staticRenderFns = [];
var __vue2_script = defineComponent({
  name: $prefix + "ColumnListGroup",
  componentName: "ColumnListGroup",
  emits: ["update:modelValue", "change"],
  props: _extends({}, $props, {
    modelValue: {},
    title: String,
    disabled: Boolean,
    size: {
      type: String,
      default: "medium"
    },
    type: {
      type: String,
      default: ""
    },
    showCheckbox: {
      type: Boolean,
      default: false
    },
    checkboxDisabled: {
      type: Boolean,
      default: false
    }
  }),
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var ColumnListGroup = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.23.0";
ColumnListGroup.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
ColumnListGroup.install = function(Vue) {
  Vue.component(ColumnListGroup.name, ColumnListGroup);
};
ColumnListGroup.version = version;

export { ColumnListGroup as default };

==> vue-column-list-group-2.24.0.tgz: package/lib/index.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/column-list-group/vue';
import { defineComponent, $prefix, $props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "w-full",
    class: _vm.type !== "list" ? "[&_[role=column-list-item]]:mb-3 [&_[role=column-list-item]:last-child]:mb-0" : "",
    attrs: {
      "data-tag": "tiny-column-list-group"
    }
  }, [_vm._t("default")], 2);
};
var staticRenderFns = [];
var __vue2_script = defineComponent({
  name: $prefix + "ColumnListGroup",
  componentName: "ColumnListGroup",
  emits: ["update:modelValue", "change"],
  props: _extends({}, $props, {
    modelValue: {},
    title: String,
    disabled: Boolean,
    size: {
      type: String,
      default: "medium"
    },
    type: {
      type: String,
      default: ""
    },
    showCheckbox: {
      type: Boolean,
      default: false
    },
    checkboxDisabled: {
      type: Boolean,
      default: false
    }
  }),
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var ColumnListGroup = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.undefined";
ColumnListGroup.model = {
  prop: "modelValue",
  event: "update:modelValue"
};
ColumnListGroup.install = function(Vue) {
  Vue.component(ColumnListGroup.name, ColumnListGroup);
};
ColumnListGroup.version = version;

export { ColumnListGroup as default };
